Module record

Module record 

VCR record/replay: proxy unmatched requests to a real provider API and save the response as a replayable fixture in a cassette file (a YAML fixture file the recorder appends to). Enabled by the record feature.

Enums

VcrMode
How the server treats incoming requests relative to the cassette.