CLI binary entry point and argument parsing.
Structs
Functions
- run
- Run the CLI with the given options, writing status output to stderr.
Returns
Ok(None)for--validate, orOk(Some(MockServer))after startup. The server runs until the returnedMockServeris dropped. - run_
with_ output - Run the CLI with the given options, writing status output to the provided writer. This variant enables tests to capture output.